@@ -22,18 +22,38 @@ class UnexpectedContentType(SnowException):
     """Unexpected content type from server"""
 
 
-class ErrorResponse(SnowException):
-    """An error was returned from server"""
+class ClientConnectionError(SnowException):
+    """Raised when there was a problem connecting to the server"""
+
+
+class RequestError(SnowException):
+    """The application returned an error in the response"""
+
+    def __init__(self, message, status):
+        self.message = message
+        self.status = status
+
+
+class ServerError(RequestError):
+    """The server returned an error in the response"""
+
+
+class UnexpectedResponseContent(RequestError):
+    """Unexpected content in response from server"""
+
+
+class IncompatiblePayloadField(SnowException):
+    """An incompatible field was found in the payload"""
+
+
+class UnknownPayloadField(SnowException):
+    """A field unknown to the schema was found in the payload"""
 
 
 class UnexpectedSchema(SnowException):
     """Schema not of snow.resource.schema.Schema type"""
 
 
-class UnexpectedResponse(SnowException):
-    """An unexpected response was received"""
-
-
 class UnexpectedValue(SnowException):
     """Typically raised when a Snow method receives unexpected input"""
 
@@ -42,10 +62,6 @@ class SchemaError(SnowException):
     """Generic exception raised on schema issues, e.g. integrity errors"""
 
 
-class NoLocationField(SchemaError):
-    """The schema lacks a __location__ field"""
-
-
 class SelectError(SnowException):
     """Raised on query builder issues"""
 
