@@ -6,11 +6,11 @@ class DeleteRequest(Request):
 
     def __init__(self, resource, object_id):
         super(DeleteRequest, self).__init__(resource)
-        self._resource_url = resource.get_url(fragments=[object_id])
+        self.base_url = resource.get_url(fragments=[object_id])
 
     async def send(self, **kwargs):
         return await self._send(**kwargs)
 
     @property
     def url(self):
-        return self._resource_url
+        return self.base_url
