@@ -7,11 +7,11 @@ class PatchRequest(Request):
     def __init__(self, resource, object_id, payload):
         super(PatchRequest, self).__init__(resource)
         self.payload = payload
-        self._resource_url = resource.get_url(fragments=[object_id])
+        self.base_url = resource.get_url(fragments=[object_id])
 
     async def send(self, **kwargs):
-        return await self._send(data=self.payload, **kwargs)
+        return await self.send_resolve(data=self.payload, **kwargs)
 
     @property
     def url(self):
-        return self._resource_url
+        return self.base_url
