@@ -1,11 +1,10 @@
 import marshmallow
 
+from ..query import BooleanOperator
 from .base import BaseField
 
-from ..query import BooleanOperator
 
-
-class Boolean(BaseField, marshmallow.fields.Boolean):
+class Boolean(marshmallow.fields.Boolean, BaseField):
     def is_true(self):
         """
         Example: active.is_true()
