@@ -1,11 +1,10 @@
 import marshmallow
 
+from ..query import EmailOperator
 from .base import BaseField
 
-from ..query import EmailOperator
 
-
-class Email(BaseField, marshmallow.fields.Email):
+class Email(marshmallow.fields.Email, BaseField):
     def changes(self):
         """
         Example: state.changes()
