@@ -1,11 +1,10 @@
 import marshmallow
 
+from ..query import NumericOperator
 from .base import BaseField
 
-from ..query import NumericOperator
 
-
-class Numeric(BaseField, marshmallow.fields.Integer):
+class Numeric(marshmallow.fields.Integer, BaseField):
     def equals(self, value):
         """
         Example: reassignment_count.equals(0)
@@ -13,7 +12,9 @@ class Numeric(BaseField, marshmallow.fields.Integer):
         All records in which the Reassignment count is nothing else but 0.
         """
 
-        return self._condition(NumericOperator.EQUALS, value, field_operator=NumericOperator.SAME)
+        return self._condition(
+            NumericOperator.EQUALS, value, field_operator=NumericOperator.SAME
+        )
 
     def not_equals(self, value):
         """
@@ -22,7 +23,9 @@ class Numeric(BaseField, marshmallow.fields.Integer):
         All records in which the value for the Reassignment count is any number but 0.
         """
 
-        return self._condition(NumericOperator.NOT_EQUALS, value, field_operator=NumericOperator.DIFFERENT)
+        return self._condition(
+            NumericOperator.NOT_EQUALS, value, field_operator=NumericOperator.DIFFERENT
+        )
 
     def less_than(self, value):
         """
@@ -31,7 +34,9 @@ class Numeric(BaseField, marshmallow.fields.Integer):
         All records in which the Impact field has a value of 1 - High.
         """
 
-        return self._condition(NumericOperator.LESS, value, field_operator=NumericOperator.Related.LESS)
+        return self._condition(
+            NumericOperator.LESS, value, field_operator=NumericOperator.Related.LESS
+        )
 
     def greater_than(self, value):
         """
@@ -40,7 +45,9 @@ class Numeric(BaseField, marshmallow.fields.Integer):
         All records in which the Impact field has a value of 3 - Low
         """
 
-        return self._condition(NumericOperator.LESS, value, field_operator=NumericOperator.Related.GREATER)
+        return self._condition(
+            NumericOperator.LESS, value, field_operator=NumericOperator.Related.GREATER
+        )
 
     def less_or_equals(self, value):
         """
@@ -49,7 +56,11 @@ class Numeric(BaseField, marshmallow.fields.Integer):
         All records in which the Impact field has a value of 1 - High or 2 - Medium.
         """
 
-        return self._condition(NumericOperator.LESS, value, field_operator=NumericOperator.Related.LESS_EQUALS)
+        return self._condition(
+            NumericOperator.LESS,
+            value,
+            field_operator=NumericOperator.Related.LESS_EQUALS,
+        )
 
     def greater_or_equals(self, value):
         """
@@ -61,7 +72,7 @@ class Numeric(BaseField, marshmallow.fields.Integer):
         return self._condition(
             NumericOperator.GREATER_EQUALS,
             value,
-            field_operator=NumericOperator.Related.GREATER_EQUALS
+            field_operator=NumericOperator.Related.GREATER_EQUALS,
         )
 
     def between(self, value1, value2):
