@@ -12,10 +12,10 @@ class Condition:
     @property
     def __str__(self):
         return (
-            (self.operator_logical or "") +
-            self.operand_left +
-            self.operator_conditional +
-            self.operand_right
+            (self.operator_logical or "")
+            + self.operand_left
+            + self.operator_conditional
+            + str(self.operand_right)
         )
 
     def _set_next(self, next_cond, operator):
